"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4776],{14776:function(e,s,t){t.r(s),t.d(s,{AssetsGroupsGlobalGraphRoot:function(){return b},default:function(){return g}});var o=t(52322),l=t(49308),a=t(2784),n=t(7267),i=t(74580),r=t(35292),u=t(72447);let d=()=>(0,o.jsx)(i.m,{title:(0,o.jsx)(r.X6,{children:"Global Asset Lineage"}),right:(0,o.jsx)(u.i,{label:"Reload definitions"})});var p=t(75442),c=t(91565),h=t(69737),f=t(68994),x=t(20171);let b=()=>{(0,h.Px)();let{0:e}=(0,n.UO)(),s=(0,n.k6)();(0,x.j)("Global Asset Lineage");let t=(0,a.useCallback)((e,t)=>{s[t]({pathname:(0,c.Cd)(e),search:s.location.search})},[s]),i=(0,a.useCallback)((e,t)=>{let o=(0,p.p)(t.assetKey,{view:"definition"});e.metaKey?window.open(o,"_blank"):s.push(o)},[s]),r=(0,a.useMemo)(()=>({hideEdgesToNodesOutsideQuery:!1}),[]);return(0,o.jsxs)(l.T,{style:{display:"flex",flexDirection:"column",paddingBottom:0},children:[(0,o.jsx)(d,{}),(0,o.jsx)(f.OK,{fetchOptions:r,options:{preferAssetRendering:!0,explodeComposites:!0},explorerPath:(0,c.Lu)(e),onChangeExplorerPath:t,onNavigateToSourceAssetNode:i,isGlobalGraph:!0})]})};var g=b}}]);
//# sourceMappingURL=4776.0f72eb4e5c821f6d.js.map