"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4787,7265],{74787:function(n,e,t){t.r(e),t.d(e,{InstanceHealthPage:function(){return v},InstanceHealthPageContent:function(){return C}});var o=t(73235),s=t(52322),i=t(14934),l=t(39013),r=t(35292),a=t(74580),c=t(2784),u=t(30623),d=t(40782),f=t(9108),x=t(77265),h=t(20958),j=t(16336),m=t(69737),p=t(20171);function g(){let n=(0,o._)(["\n  query InstanceHealthQuery {\n    instance {\n      id\n      ...InstanceHealthFragment\n    }\n  }\n\n  ","\n"]);return g=function(){return n},n}let C=()=>{(0,m.Px)(),(0,p.j)("Daemons");let n=(0,h.aM)(b,{notifyOnNetworkStatusChange:!0}),e=(0,j.C4)(n,j.dT),{loading:t,data:o}=n;return(0,s.jsxs)("div",{style:{overflowY:"auto"},children:[(0,s.jsxs)(i.x,{padding:{vertical:16,horizontal:24},flex:{direction:"row",alignItems:"center",justifyContent:"space-between"},children:[(0,s.jsx)(r.pm,{children:"Daemon statuses"}),(0,s.jsx)("div",{children:(0,s.jsx)(j.xi,{refreshState:e})})]}),!t||(null==o?void 0:o.instance)?(null==o?void 0:o.instance)?(0,s.jsx)(u.W,{daemonStatuses:o.instance.daemonHealth.allDaemonStatuses}):null:(0,s.jsx)(i.x,{padding:{horizontal:24},style:{color:l.$()},children:"Loading…"})]})},v=()=>{let{pageTitle:n}=(0,c.useContext)(f.N);return(0,s.jsxs)(s.Fragment,{children:[(0,s.jsx)(a.m,{title:(0,s.jsx)(r.X6,{children:n}),tabs:(0,s.jsx)(x.Z,{tab:"health"})}),(0,s.jsx)(C,{})]})};e.default=v;let b=(0,h.Ps)(g(),d.O)},77265:function(n,e,t){t.d(e,{Z:function(){return C}});var o=t(52322),s=t(14934),i=t(73407),l=t(2784),r=t(9108),a=t(35232),c=t(16336),u=t(21993),d=t(39013),f=t(29185),x=t(83613);let h=(0,l.memo)(()=>{let{daemons:n}=(0,l.useContext)(x.Z);return n?(0,o.jsx)(f.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(u.JO,{name:"warning",color:d.qr()})}):null});var j=t(35002),m=t(79106);let p=(0,l.memo)(n=>{let{placeholder:e}=n,{codeLocations:t}=(0,l.useContext)(x.Z);return t?"spinner"===t.type?(0,o.jsx)(j.u,{content:t.content,placement:"bottom",children:(0,o.jsx)(m.$,{purpose:"body-text",fillColor:d.md()})}):(0,o.jsx)(f.a,{content:t.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(u.JO,{name:"warning",color:d.qr()})}):e?(0,o.jsx)("div",{style:{width:"16px"}}):null});var g=t(89918);let C=n=>{let{refreshState:e,tab:t}=n,{healthTitle:u}=(0,l.useContext)(r.N),d=(0,a._)();return(0,o.jsxs)(s.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,o.jsxs)(i.mQ,{selectedTabId:t,children:[(0,o.jsx)(g.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,o.jsx)(p,{placeholder:!1})}),(0,o.jsx)(g.f,{id:"health",title:u,to:"/health",icon:(0,o.jsx)(h,{})}),d?(0,o.jsx)(g.f,{id:"concurrency",title:"Concurrency limits",to:"/concurrency"}):null,d?(0,o.jsx)(g.f,{id:"config",title:"Configuration",to:"/config"}):null]}),e?(0,o.jsx)(s.x,{padding:{bottom:8},children:(0,o.jsx)(c.xi,{refreshState:e})}):null]})}},35232:function(n,e,t){t.d(e,{_:function(){return l}});var o=t(73235),s=t(20958);function i(){let n=(0,o._)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"]);return i=function(){return n},n}let l=()=>{var n;return!!(null===(n=(0,s.aM)(r).data)||void 0===n?void 0:n.instance.hasInfo)},r=(0,s.Ps)(i())}}]);
//# sourceMappingURL=4787.8eb13ab115ba3308.js.map