"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9077],{99077:function(o,r,e){e.r(r),e.d(r,{DateRangePickerWrapper:function(){return t}});var a=e(52322),n=e(39013);e(2784);var c=e(9585),l=e(35505);e(85229),e(96259);let t=o=>(0,a.jsx)(d,{children:(0,a.jsx)(c.DateRangePicker,{...o})}),d=l.ZP.div.withConfig({componentId:"sc-fbb33b6a-0"})([".DateRangePickerInput{background-color:",";}.DateRangePickerInput__withBorder{border-color:",";}.DateInput{background-color:",";}.DateRangePickerInput_arrow_svg{fill:",";}.DateInput_input{background-color:",";color:",";}.DateInput_input::placeholder{color:",";}.DateInput_input__focused{border-color:",";outline:none;}.DateInput_fangShape{fill:",";}.DateInput_fangStroke{stroke:",";}.DateRangePicker_picker{background-color:",";color:",";}.DayPicker{background-color:",";color:",";}.DayPickerNavigation_button__default{background-color:",";border-color:",";:hover{border-color:",";}}.DayPickerNavigation_svg__horizontal{fill:",";}.DayPicker_weekHeader{color:",";}.CalendarMonthGrid,.CalendarMonth{background-color:",";color:",";}.CalendarMonth_caption{color:",";}.CalendarDay__default{background-color:",";border-color:",";color:",";:hover{background-color:",";border-color:",";}}.CalendarDay__selected{background-color:",";:active,:hover{border-color:",";}}.CalendarDay__hovered_span,.CalendarDay__hovered_span_3{background-color:",";border-color:",";}"],n.v8(),n.im(),n.v8(),n.Aw(),n.v8(),n.Ep(),n.$(),n.L$(),n.gJ(),n.wL(),n.gJ(),n.Ep(),n.gJ(),n.Ep(),n.gJ(),n.im(),n.Wn(),n.$(),n.Aw(),n.gJ(),n.Ep(),n.$(),n.gJ(),n.wL(),n.$(),n.Dd(),n.wL(),n.i3(),n.wL(),n.Dd(),n.wL());r.default=t}}]);
//# sourceMappingURL=9077.e8f4916ed8ad656b.js.map