"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[8072],{48072:function(s,l,t){t.r(l),t.d(l,{MarkdownWithPlugins:function(){return p}});var e,h,j,a=t(52322),r=t(73078),o=t(13723),i=t(29256),n=t(36221),u=t(33752);t(83518);let c={...i.R,protocols:{src:[...null!==(j=null===(e=i.R.protocols)||void 0===e?void 0:e.src)&&void 0!==j?j:[],"data"]},attributes:{...i.R.attributes,span:[...(null===(h=i.R.attributes)||void 0===h?void 0:h.span)||[],["className","hljs-addition","hljs-attr","hljs-attribute","hljs-built_in","hljs-bullet","hljs-char","hljs-code","hljs-comment","hljs-deletion","hljs-doctag","hljs-emphasis","hljs-formula","hljs-keyword","hljs-link","hljs-literal","hljs-meta","hljs-name","hljs-number","hljs-operator","hljs-params","hljs-property","hljs-punctuation","hljs-quote","hljs-regexp","hljs-section","hljs-selector-attr","hljs-selector-class","hljs-selector-id","hljs-selector-pseudo","hljs-selector-tag","hljs-string","hljs-strong","hljs-subst","hljs-symbol","hljs-tag","hljs-template-tag","hljs-template-variable","hljs-title","hljs-type","hljs-variable"]]}},p=s=>(0,a.jsx)(r.D,{...s,remarkPlugins:[u.Z],rehypePlugins:[o.Z,[n.Z,c]]});l.default=p}}]);
//# sourceMappingURL=8072.b87569d16da8eff0.js.map