"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7265],{77265:function(n,t,e){e.d(t,{Z:function(){return C}});var o=e(52322),i=e(14934),s=e(73407),l=e(2784),r=e(9108),c=e(35232),a=e(16336),u=e(21993),f=e(39013),d=e(29185),x=e(83613);let h=(0,l.memo)(()=>{let{daemons:n}=(0,l.useContext)(x.Z);return n?(0,o.jsx)(d.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(u.JO,{name:"warning",color:f.qr()})}):null});var j=e(35002),m=e(79106);let p=(0,l.memo)(n=>{let{placeholder:t}=n,{codeLocations:e}=(0,l.useContext)(x.Z);return e?"spinner"===e.type?(0,o.jsx)(j.u,{content:e.content,placement:"bottom",children:(0,o.jsx)(m.$,{purpose:"body-text",fillColor:f.md()})}):(0,o.jsx)(d.a,{content:e.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(u.JO,{name:"warning",color:f.qr()})}):t?(0,o.jsx)("div",{style:{width:"16px"}}):null});var b=e(89918);let C=n=>{let{refreshState:t,tab:e}=n,{healthTitle:u}=(0,l.useContext)(r.N),f=(0,c._)();return(0,o.jsxs)(i.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,o.jsxs)(s.mQ,{selectedTabId:e,children:[(0,o.jsx)(b.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,o.jsx)(p,{placeholder:!1})}),(0,o.jsx)(b.f,{id:"health",title:u,to:"/health",icon:(0,o.jsx)(h,{})}),f?(0,o.jsx)(b.f,{id:"concurrency",title:"Concurrency limits",to:"/concurrency"}):null,f?(0,o.jsx)(b.f,{id:"config",title:"Configuration",to:"/config"}):null]}),t?(0,o.jsx)(i.x,{padding:{bottom:8},children:(0,o.jsx)(a.xi,{refreshState:t})}):null]})}},35232:function(n,t,e){e.d(t,{_:function(){return l}});var o=e(73235),i=e(20958);function s(){let n=(0,o._)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"]);return s=function(){return n},n}let l=()=>{var n;return!!(null===(n=(0,i.aM)(r).data)||void 0===n?void 0:n.instance.hasInfo)},r=(0,i.Ps)(s())}}]);
//# sourceMappingURL=7265.ca469fc64bcfda77.js.map