(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2888],{86570:function(n,t,e){(window.__NEXT_P=window.__NEXT_P||[]).push(["/_app",function(){return e(27807)}])},27807:function(n,t,e){"use strict";e.r(t),e.d(t,{default:function(){return s}});var i=e(52322),r=e(97729),c=e.n(r);function s(n){let{Component:t,pageProps:e}=n;return(0,i.jsxs)(i.Fragment,{children:[(0,i.jsxs)(c(),{children:[(0,i.jsx)("meta",{charSet:"utf-8"}),(0,i.jsx)("meta",{name:"viewport",content:"width=device-width, initial-scale=1, shrink-to-fit=no"}),(0,i.jsx)("meta",{name:"theme-color",content:"#000000"}),(0,i.jsx)("meta",{name:"slack-app-id",content:"A036YAU6RT7"}),(0,i.jsx)("title",{children:"Dagster"})]}),(0,i.jsx)(t,{...e})]})}},97729:function(n,t,e){n.exports=e(50044)}},function(n){var t=function(t){return n(n.s=t)};n.O(0,[9774,179],function(){return t(86570),t(69442)}),_N_E=n.O()}]);
//# sourceMappingURL=_app-ffbc9de9165dc65b.js.map