"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3738],{94853:function(e,n,t){t.d(n,{N:function(){return s},l:function(){return a}});var o=t(52322),r=t(14934),i=t(21993),c=t(39013),l=t(35505);let a=32,s=e=>{let{expanded:n,onClick:t,children:c,rightElement:l}=e;return(0,o.jsx)(d,{$open:n,onClick:t,children:(0,o.jsxs)(r.x,{flex:{alignItems:"center",justifyContent:"space-between"},padding:{horizontal:24},children:[c,(0,o.jsxs)(r.x,{flex:{alignItems:"center",gap:8},children:[l,(0,o.jsx)(r.x,{margin:{top:2},children:(0,o.jsx)(i.JO,{name:"arrow_drop_down"})})]})]})})},d=l.ZP.button.withConfig({componentId:"sc-59cc4c28-0"})(["background-color:",";border:0;box-shadow:inset 0px -1px 0 ",",inset 0px 1px 0 ",";color:",";cursor:pointer;display:block;padding:0;width:100%;margin:0;height:","px;text-align:left;:focus,:active{outline:none;}:hover{background-color:",";}",'[aria-label="arrow_drop_down"]{transition:transform 100ms linear;',"}"],c.gJ(),c.wL(),c.wL(),c.$(),a,c._c(),i.a1,e=>{let{$open:n}=e;return n?null:"transform: rotate(-90deg);"})},83738:function(e,n,t){t.d(n,{HB:function(){return b},_$:function(){return m},mq:function(){return j},vG:function(){return w},v5:function(){return C}});var o=t(52322),r=t(39013),i=t(35292),c=t(2784),l=t(35505),a=t(34219),s=t(14934),d=t(21993),u=t(94853),h=t(65822);let f=e=>{let{repoName:n,repoLocation:t,showLocation:i,...c}=e,l=n===h.Js;return(0,o.jsx)(u.N,{...c,children:(0,o.jsxs)(s.x,{flex:{alignItems:"center",gap:8},children:[(0,o.jsx)(d.JO,{name:"folder",color:r.md()}),(0,o.jsxs)("div",{children:[(0,o.jsx)(x,{children:l?t:n}),i&&!l?(0,o.jsx)(p,{children:"@".concat(t)}):null]})]})})},x=l.ZP.span.withConfig({componentId:"sc-bd1c799-0"})(["font-weight:600;"]),p=l.ZP.span.withConfig({componentId:"sc-bd1c799-1"})(["font-weight:400;color:",";"],r.Aw());var g=t(17008);let w=e=>{let{repoAddress:n,height:t,start:r,expanded:i,onToggle:c,onToggleAll:l,showLocation:a,rightElement:s}=e;return(0,o.jsx)(g.X2,{$height:t,$start:r,children:(0,o.jsx)(f,{repoName:n.name,repoLocation:n.location,expanded:i,onClick:e=>e.getModifierState("Shift")?l(!i):c(n),showLocation:a,rightElement:s})})},m=(0,c.forwardRef)((e,n)=>{let{index:t,repoAddress:r,expanded:i,onToggle:c,onToggleAll:l,showLocation:a,rightElement:s}=e;return(0,o.jsx)("div",{ref:n,"data-index":t,children:(0,o.jsx)(f,{repoName:r.name,repoLocation:r.location,expanded:i,onClick:e=>e.getModifierState("Shift")?l(!i):c(r),showLocation:a,rightElement:s})})}),j=e=>{let{queryResult:n,noneString:t="None"}=e,{called:i,loading:c,data:l}=n;return(0,o.jsx)("div",{style:{color:r.$()},children:i&&(!c||l)?t:"Loading"})},b=e=>{let{children:n}=e;return(0,o.jsx)(v,{children:(0,o.jsx)(i.YS,{children:n})})},v=l.ZP.div.withConfig({componentId:"sc-b9e903b5-0"})(["max-width:100%;overflow:hidden;text-overflow:ellipsis;","{color:",";white-space:nowrap;}"],i.YS,r.$()),C=e=>{let n=(0,a.FE)("DelayedRowQuery");c.useEffect(()=>{let t=setTimeout(()=>{e(),n.completeDependency(a.Os.SUCCESS)},100);return()=>{clearTimeout(t)}},[e,n])}}}]);
//# sourceMappingURL=3738.8b3107d3ce4600d6.js.map