"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5521,7265],{5521:function(n,e,t){t.r(e),t.d(e,{INSTANCE_CONFIG_QUERY:function(){return w},InstanceConfigContent:function(){return b},InstanceConfigRoot:function(){return y}});var o=t(73235),i=t(52322);t(19757);var r=t(39013),s=t(14934),l=t(79106),c=t(35292),a=t(20156),f=t(74580),u=t(2784),d=t(35505),x=t(9108),h=t(77265),g=t(20958),m=t(16336),j=t(69737),p=t(20171);function C(){let n=(0,o._)(["\n  query InstanceConfigQuery {\n    version\n    instance {\n      id\n      info\n    }\n  }\n"]);return C=function(){return n},n}let v=(0,d.vJ)([".CodeMirror.cm-s-instance-config.cm-s-instance-config{background-color:",";box-shadow:0 1px 0 ",";color:",";height:100%;.config-highlight.config-highlight{background-color:",";}}"],r.v8(),r.wL(),r.Ep(),r.WA()),b=(0,u.memo)(()=>{(0,j.Px)(),(0,p.j)("Configuration");let n=(0,g.aM)(w,{notifyOnNetworkStatusChange:!0}),e=(0,m.C4)(n,m.dT),{data:t}=n,o=null==t?void 0:t.instance.info,r=(0,u.useMemo)(()=>({onReady:n=>{let e=document.location.hash;if(e){let t=new RegExp("^".concat(e.slice(1),":")),o=n.getSearchCursor(t);o.findNext()&&(n.markText(o.from(),o.to(),{className:"config-highlight"}),n.scrollIntoView(o.from()))}}}),[]);return t?(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(v,{}),(0,i.jsxs)(s.x,{padding:{vertical:16,horizontal:24},border:"bottom",flex:{direction:"row",alignItems:"center",justifyContent:"space-between"},children:[(0,i.jsxs)(c.pm,{children:["Dagster version: ",(0,i.jsx)(c.EK,{style:{fontSize:"16px"},children:t.version})]}),(0,i.jsx)(m.xi,{refreshState:e})]}),(0,i.jsx)("div",{style:{flex:1,overflow:"hidden"},children:(0,i.jsx)(a.u,{value:o||"",options:{readOnly:!0,lineNumbers:!0,mode:"yaml"},handlers:r,theme:["instance-config"]})})]}):(0,i.jsx)(s.x,{padding:{vertical:64},children:(0,i.jsx)(l.$,{purpose:"section"})})}),y=()=>{let{pageTitle:n}=(0,u.useContext)(x.N);return(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(f.m,{title:(0,i.jsx)(c.X6,{children:n}),tabs:(0,i.jsx)(h.Z,{tab:"config"})}),(0,i.jsx)(b,{})]})};e.default=y;let w=(0,g.Ps)(C())},77265:function(n,e,t){t.d(e,{Z:function(){return C}});var o=t(52322),i=t(14934),r=t(73407),s=t(2784),l=t(9108),c=t(35232),a=t(16336),f=t(21993),u=t(39013),d=t(29185),x=t(83613);let h=(0,s.memo)(()=>{let{daemons:n}=(0,s.useContext)(x.Z);return n?(0,o.jsx)(d.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(f.JO,{name:"warning",color:u.qr()})}):null});var g=t(35002),m=t(79106);let j=(0,s.memo)(n=>{let{placeholder:e}=n,{codeLocations:t}=(0,s.useContext)(x.Z);return t?"spinner"===t.type?(0,o.jsx)(g.u,{content:t.content,placement:"bottom",children:(0,o.jsx)(m.$,{purpose:"body-text",fillColor:u.md()})}):(0,o.jsx)(d.a,{content:t.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,o.jsx)(f.JO,{name:"warning",color:u.qr()})}):e?(0,o.jsx)("div",{style:{width:"16px"}}):null});var p=t(89918);let C=n=>{let{refreshState:e,tab:t}=n,{healthTitle:f}=(0,s.useContext)(l.N),u=(0,c._)();return(0,o.jsxs)(i.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,o.jsxs)(r.mQ,{selectedTabId:t,children:[(0,o.jsx)(p.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,o.jsx)(j,{placeholder:!1})}),(0,o.jsx)(p.f,{id:"health",title:f,to:"/health",icon:(0,o.jsx)(h,{})}),u?(0,o.jsx)(p.f,{id:"concurrency",title:"Concurrency limits",to:"/concurrency"}):null,u?(0,o.jsx)(p.f,{id:"config",title:"Configuration",to:"/config"}):null]}),e?(0,o.jsx)(i.x,{padding:{bottom:8},children:(0,o.jsx)(a.xi,{refreshState:e})}):null]})}},35232:function(n,e,t){t.d(e,{_:function(){return s}});var o=t(73235),i=t(20958);function r(){let n=(0,o._)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"]);return r=function(){return n},n}let s=()=>{var n;return!!(null===(n=(0,i.aM)(l).data)||void 0===n?void 0:n.instance.hasInfo)},l=(0,i.Ps)(r())}}]);
//# sourceMappingURL=5521.c6e7410b5ab4fab5.js.map